==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property destinationAddresses
 * @property destinationPortRanges
 * @property protocol
 * @property sourceAddresses
 * @property sourcePortRanges
 */
public data class GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader(
    public val destinationAddresses: List<String>,
    public val destinationPortRanges:
    List<GetNetworkInsightsAnalysisReturnPathComponentOutboundHeaderDestinationPortRange>,
    public val protocol: String,
    public val sourceAddresses: List<String>,
    public val sourcePortRanges:
    List<GetNetworkInsightsAnalysisReturnPathComponentOutboundHeaderSourcePortRange>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader):
            GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader =
            GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader(
                destinationAddresses = javaType.destinationAddresses().map({ args0 -> args0 }),
                destinationPortRanges = javaType.destinationPortRanges().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.GetNetworkInsightsAnalysisReturnPathComponentOutboundHeaderDestinationPortRange.Companion.toKotlin(args0)
                    })
                }),
                protocol = javaType.protocol(),
                sourceAddresses = javaType.sourceAddresses().map({ args0 -> args0 }),
                sourcePortRanges = javaType.sourcePortRanges().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.GetNetworkInsightsAnalysisReturnPathComponentOutboundHeaderSourcePortRange.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property destinationAddresses
 * @property destinationPortRanges
 * @property protocol
 * @property sourceAddresses
 * @property sourcePortRanges
 */
public data class GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader(
    public val destinationAddresses: List<String>,
    public val destinationPortRanges: List<GetNetworkInsightsAnalysisReturnPathComponentOutboundHeaderDestinationPortRange>,
    public val protocol: String,
    public val sourceAddresses: List<String>,
    public val sourcePortRanges: List<GetNetworkInsightsAnalysisReturnPathComponentOutboundHeaderSourcePortRange>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader): GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader =
            GetNetworkInsightsAnalysisReturnPathComponentOutboundHeader(
                destinationAddresses = javaType.destinationAddresses().map({ args0 -> args0 }),
                destinationPortRanges = javaType.destinationPortRanges().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.GetNetworkInsightsAnalysisReturnPathComponentOutboundHeaderDestinationPortRange.Companion.toKotlin(args0)
                    })
                }),
                protocol = javaType.protocol(),
                sourceAddresses = javaType.sourceAddresses().map({ args0 -> args0 }),
                sourcePortRanges = javaType.sourcePortRanges().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.GetNetworkInsightsAnalysisReturnPathComponentOutboundHeaderSourcePortRange.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
